@@ -12,11 +12,12 @@ __all__ = (
     'np2video',
     'Run',
     'run',
+    'runcv',
     'sound_chunks',
     'video_frames')
 
 try:
-    import numm.opencv as opencv
+    import opencv
 except ImportError:
     opencv = None
 
@@ -24,3 +25,4 @@ from numm.sound import sound2np, np2sound, sound_chunks
 from numm.image import image2np, np2image
 from numm.video import video2np, np2video, video_frames
 from numm.async import Run, run
+from numm.asyncCV import runcv
