@@ -17,7 +17,8 @@ import gobject
 import gst
 import numpy
 
-import numm.term
+if not sys.platform.startswith('win'):
+    import numm.term
 
 __all__ = (
     'Run',
@@ -75,12 +76,12 @@ def _make_video_in_bin(src=None):
 
 def _make_video_out_bin(sink=None):
     if sink is None:
-        if sys.platform.startswith('win'):
-            # Work around the fact that autovideosink attempts
-            # d3dvideosink, which sometimes doesn't work.
-            sink = gst.element_factory_make("directdrawsink")
-        else:
-            sink = gst.element_factory_make("autovideosink")
+        # if sys.platform.startswith('win'):
+        #     # Work around the fact that autovideosink attempts
+        #     # d3dvideosink, which sometimes doesn't work.
+        #     sink = gst.element_factory_make("directdrawsink")
+        # else:
+        sink = gst.element_factory_make("autovideosink")
 
     sink.props.name = 'video_sink'
 
@@ -267,7 +268,7 @@ class Run(Lockable):
 
     def _got_audio_data(self, appsink):
         buffer = appsink.emit('pull-buffer')
-        a = numpy.fromstring(buffer, dtype=numpy.int16).view(NummBuffer)
+        a = numpy.fromstring(str(buffer), dtype=numpy.int16).view(NummBuffer)
         a = a.reshape((a.shape[0] / 2, 2))
         a.timestamp = buffer.timestamp
 
@@ -322,7 +323,7 @@ class Run(Lockable):
 
     def _got_video_data(self, appsink):
         buffer = appsink.emit('pull-buffer')
-        a = numpy.fromstring(buffer, dtype=numpy.uint8).view(NummBuffer)
+        a = numpy.fromstring(str(buffer), dtype=numpy.uint8).view(NummBuffer)
         a = a.reshape((240, 320, 3))
         a.timestamp = buffer.timestamp
 
@@ -625,6 +626,10 @@ def run(**kw):
     """
 
     # Point of inversion of control.
-    run = Run(**kw)
+    if sys.platform.startswith('win') or sys.platform.startswith('darwin'):
+        import numm.asyncCV
+        run = numm.asyncCV.RunCV(**kw)
+    else:
+        run = Run(**kw)
     run.run()
 
