@@ -1,8 +1,8 @@
 
 import sys
+import traceback
 
 import gio
-import numpy
 import numm.async
 
 def _load_module(path):
@@ -20,22 +20,14 @@ def _monitor_changes(path, cb):
     monitor = gio.File(path).monitor()
     monitor.connect('changed', cb_)
 
-class FunctionProxy(object):
-    def __init__(self, func):
-        self.func = func
-
-    def __call__(self, *a, **kw):
-        if self.func is  None:
-            return
-
+def print_errors(f):
+    def g(*a, **kw):
         try:
-            self.func(*a, **kw)
+            f(*a, **kw)
         except Exception:
-            import traceback
             traceback.print_exc()
 
-    def __nonzero__(self):
-        return self.func is not None
+    return g
 
 def main():
     if len(sys.argv) < 2:
@@ -43,11 +35,7 @@ def main():
 
     path = sys.argv[1]
     sys.argv[1:] = sys.argv[2:]
-
-    cb_args = {}
-
-    for callback in numm.async.callbacks:
-        cb_args[callback] = FunctionProxy(None)
+    run = numm.async.Run()
 
     def load():
         print 'load!'
@@ -55,13 +43,14 @@ def main():
 
         for callback in numm.async.callbacks:
             f = module.get(callback) or module.get(callback + 'put')
-            cb_args[callback].func = f
+            setter = getattr(run, 'set_' + callback, None)
+
+            if f is not None:
+                setter(print_errors(f))
+            else:
+                setter(None)
 
     load()
-
-    if not numpy.array(cb_args.values()).any():
-        print 'no callbacks found'
-        sys.exit(1)
-
     _monitor_changes(path, load)
-    numm.async.run(**cb_args)
+    run.run()
+
