@@ -8,10 +8,24 @@ Images are represented as arrays with shape (height, width, 3).
 import numpy
 import Image
 
-def image2np(path):
+def _get_dimensions(im, width, height):
+    "preserve aspect if width or height is None"
+    if width and height:
+        return (width, height)
+    aspect = im.size[0]/float(im.size[1])
+    if width:
+        return (width, int(width/aspect))
+    else:
+        return (int(height*aspect), height)
+
+def image2np(path, width=None, height=None):
     "Load an image file into an array."
 
     im = Image.open(path)
+
+    if width or height:
+        im = im.resize(_get_dimensions(im, width, height), 1)
+
     im = im.convert('RGB')
     np = numpy.asarray(im, dtype=numpy.uint8)
     return np
@@ -20,8 +34,12 @@ def np2image(np, path):
     "Save an image array to a file."
 
     assert np.dtype == numpy.uint8, "nparr must be uint8"
+    if len(np.shape) > 2 and np.shape[2] == 3:
+        mode = 'RGB'
+    else:
+        mode = 'L'
     im = Image.fromstring(
-        'RGB', (np.shape[1], np.shape[0]), np.tostring())
+        mode, (np.shape[1], np.shape[0]), np.tostring())
     im.save(path)
 
 if __name__ == '__main__':
