@@ -11,4 +11,5 @@ if 'NOSE_WITH_DOCTEST' not in os.environ:
     os.environ['NOSE_WITH_DOCTEST'] = '1'
 
 if __name__ == '__main__':
-    nose.core.run()
+    if not nose.core.run():
+        raise SystemExit(1)
