@@ -7,12 +7,13 @@ def test_file(name):
     return os.path.join(os.path.dirname(__file__), 'data', name)
 
 class Tmp(object):
-    def __init__(self):
+    def __init__(self, suffix=''):
         self.path = None
+        self.suffix = suffix
 
     def __enter__(self):
         assert self.path is None
-        (_fd, self.path) = tempfile.mkstemp()
+        (_fd, self.path) = tempfile.mkstemp(suffix=self.suffix)
         return self.path
 
     def __exit__(self, et, e, tb):
